import matplotlib.pyplot as plt
import numpy as np

# Input flood pulse variable data of choice (this is Peak Day)
data_1990s =  [171, 186, 161, 199, 175, 169, 192, 171, 166, 172]
data_2000s =[178, 180, 177, 191, 167, 155, 188, 192, 170, 151]
data_2030s = [199, 204, 174, 160, 166, 173, 160, 142, 150, 166]
data_2050s =  [178, 162, 169, 158, 154, 177, 175, 178, 177, 154]
data_2070s = [171, 170, 171, 182, 173, 160, 193, 169, 172, 178]
data_2031 =  [177, 176, 170, 155, 191, 181, 182, 153, 167, 161]
data_2051 = [170, 181, 172, 175, 187, 189, 170, 175, 183, 171]
data_2071 = [155, 193, 175, 189, 162, 199, 172, 177, 165, 166]
data_2032 =[195, 179, 180, 162, 192, 143, 168, 170, 183, 175]
data_2052 =  [170, 180, 176, 184, 181, 176, 169, 162, 179, 181]
data_2072 = [188, 174, 189, 176, 192, 172, 176, 169, 168, 162]

# Combine the data into a list
data = [
    data_1990s, data_2000s,
    data_2030s, data_2050s, data_2070s,
    data_2031, data_2051, data_2071,
    data_2032, data_2052, data_2072
]

# Create a boxplot with equal widths
fig, ax = plt.subplots()

# Set the box width to 0.6 for all boxplots
boxprops = dict(linewidth=1, color="black")
bp = ax.boxplot(data[:2], positions=[1, 2], labels=['1990s', '2000s'], widths=0.4, boxprops=boxprops, patch_artist=True)
bp1 = ax.boxplot(data[2:5], positions=[4, 5, 6], labels=['2030s', '2050s', '2070s'], widths=0.4, boxprops=boxprops, patch_artist=True)
bp2 = ax.boxplot(data[5:8], positions=[8, 9, 10], labels=['2031', '2051', '2071'], widths=0.4, boxprops=boxprops, patch_artist=True)
bp3 = ax.boxplot(data[8:], positions=[12, 13, 14], labels=['2032', '2052', '2072'], widths=0.4, boxprops=boxprops, patch_artist=True)

# Set the color of the boxplots
colors = [['lightgrey', 'darkgrey'],            # Colors for bp, historical
          ['#44AA99', '#DDCC77', '#CC6677'],  # Colors for bp1, ssp126
          ['#44AA99', '#DDCC77', '#CC6677'],  # Colors for bp2, ssp370
          ['#44AA99', '#DDCC77', '#CC6677']]  # Colors for bp3, ssp585

for i, bplot in enumerate([bp, bp1, bp2, bp3]):
    for j, patch in enumerate(bplot['boxes']):
        patch.set_facecolor(colors[i][j])

# Set the mean line color to black
for median in bp['medians']:
    median.set(color='black', linewidth=1)

for median in bp1['medians']:
    median.set(color='black', linewidth=1)

for median in bp2['medians']:
    median.set(color='black', linewidth=1)

for median in bp3['medians']:
    median.set(color='black', linewidth=1)

# Add vertical lines at positions 3, 7, and 11
ax.axvline(x=3, color='gray', linestyle='--', linewidth=1)
ax.axvline(x=7, color='gray', linestyle='--', linewidth=1)
ax.axvline(x=11, color='gray', linestyle='--', linewidth=1)

# Remove the x-axis ticks and tick labels
ax.set_xticks([])

# Add custom labels in between the vertical lines below the x-axis
custom_labels = ['Baseline', 'SSP 1-2.6', 'SSP 3-7.0', 'SSP 5-8.5']
custom_positions = [1.5, 5, 9, 12.75]

for i, label in zip(custom_positions, custom_labels):
    ax.text(i, 130, label, ha='center', va='center', weight = 'bold')  # Adjust the y-coordinate to -10 or any other suitable value

# Customize the appearance of outliers
for bplot in [bp, bp1, bp2, bp3]:
    for flier in bplot['fliers']:
        flier.set(marker='o', markersize=4, markerfacecolor='grey', markeredgecolor='grey', alpha=0.7)

# Set the x-axis limits
ax.set_xlim(0.5, 15)

# Set the y-axis limits
ax.set_ylim(140, 210)  # Adjust the limits according to range required


# Set labels and title
ax.set_ylabel('Day of peak flood extent', weight = 'bold')


# Set aspect ratio to auto
ax.set_aspect('auto')

# Adjust bottom margin
plt.subplots_adjust(bottom=0.1)

# Show the plot
plt.show()






